@@ -14,7 +14,7 @@ from urllib.error import URLError
 from urllib.error import HTTPError
 
 import graphsignal
-from graphsignal import metrics_pb2
+from graphsignal.proto import profiles_pb2
 
 logger = logging.getLogger('graphsignal')
 
@@ -23,22 +23,22 @@ class Uploader(object):
     MAX_BUFFER_SIZE = 2500
 
     def __init__(self):
-        self.collector_url = 'https://log-api.graphsignal.com'
+        self.profile_api_url = 'https://profile-api.graphsignal.com'
         self.buffer = []
         self.buffer_lock = threading.Lock()
         self.flush_lock = threading.Lock()
 
     def configure(self):
-        if 'GRAPHSIGNAL_LOG_API_URL' in os.environ:
-            self.collector_url = os.environ['GRAPHSIGNAL_LOG_API_URL']
+        if 'GRAPHSIGNAL_PROFILE_API_URL' in os.environ:
+            self.profile_api_url = os.environ['GRAPHSIGNAL_PROFILE_API_URL']
 
     def clear(self):
         with self.buffer_lock:
             self.buffer = []
 
-    def upload_window(self, window):
+    def upload_profile(self, profile):
         with self.buffer_lock:
-            self.buffer.append(window)
+            self.buffer.append(profile)
             if len(self.buffer) > self.MAX_BUFFER_SIZE:
                 self.buffer = self.buffer[-self.MAX_BUFFER_SIZE:]
 
@@ -54,30 +54,30 @@ class Uploader(object):
                 self.buffer = []
             try:
                 upload_start = time.time()
-                upload_request = metrics_pb2.UploadRequest()
-                upload_request.windows.extend(outgoing)
-                upload_request.upload_ts = _timestamp()
+                upload_request = profiles_pb2.UploadRequest()
+                upload_request.ml_profiles.extend(outgoing)
+                upload_request.upload_ms = int(time.time() * 1e3)
                 resp = self._post(
-                    'metrics', upload_request.SerializeToString())
-                upload_response = metrics_pb2.UploadResponse()
+                    'profiles', upload_request.SerializeToString())
+                upload_response = profiles_pb2.UploadResponse()
                 upload_response.ParseFromString(resp)
                 logger.debug(
                     'Upload took %.3f sec', time.time() - upload_start)
             except URLError:
                 logger.debug(
-                    'Failed uploading metrics, will retry', exc_info=True)
+                    'Failed uploading profiles, will retry', exc_info=True)
                 with self.buffer_lock:
                     self.buffer[:0] = outgoing
             except Exception:
                 logger.error(
-                    'Error uploading metrics', exc_info=True)
+                    'Error uploading profiles', exc_info=True)
 
     def _post(self, endpoint, data):
         logger.debug('Posting data to %s/%s',
-                     self.collector_url, endpoint)
+                     self.profile_api_url, endpoint)
 
         api_key_64 = _base64_encode(
-            graphsignal._get_config().api_key + ':').replace('\n', '')
+            graphsignal._agent.api_key + ':').replace('\n', '')
         headers = {
             'Accept-Encoding': 'gzip',
             'Authorization': "Basic %s" % api_key_64,
@@ -96,7 +96,7 @@ class Uploader(object):
         else:
             data_gzip = gzip_out.getvalue()
         request = Request(
-            url=self.collector_url + '/' + endpoint,
+            url=self.profile_api_url + '/' + endpoint,
             data=data_gzip,
             headers=headers)
 
@@ -116,9 +116,5 @@ class Uploader(object):
             raise herr
 
 
-def _timestamp():
-    return int(time.time())
-
-
 def _base64_encode(s):
     return base64.b64encode(s.encode('utf-8')).decode('utf-8')
